function [ret,x0,str,ts,xts]=blocsimu(t,x,u,flag);
%BLOCSIMU	is the M-file description of the SIMULINK system named BLOCSIMU.
%	The block-diagram can be displayed by typing: BLOCSIMU.
%
%	SYS=BLOCSIMU(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes BLOCSIMU to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling BLOCSIMU with a FLAG of zero:
%	[SIZES]=BLOCSIMU([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[143,84,340,510])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')


%     Subsystem  'Subsystem'.

new_system([sys,'/','Subsystem'])
set_param([sys,'/','Subsystem'],'Location',[262,60,1207,525])

add_block('built-in/Note',[sys,'/','Subsystem/Temps'])
set_param([sys,'/','Subsystem/Temps'],...
		'position',[130,285,135,290])

add_block('built-in/Note',[sys,'/',['Subsystem/Champ magntique',13,'terrestre',13,'(repre satellite)']])
set_param([sys,'/',['Subsystem/Champ magntique',13,'terrestre',13,'(repre satellite)']],...
		'position',[130,120,135,125])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace5'])
set_param([sys,'/','Subsystem/To Workspace5'],...
		'hide name',0,...
		'mat-name','champ_pulse',...
		'buffer','20000',...
		'position',[730,213,850,247])

add_block('built-in/Note',[sys,'/','Subsystem/B(n)'])
set_param([sys,'/','Subsystem/B(n)'],...
		'position',[535,175,540,180])

add_block('built-in/Note',[sys,'/','Subsystem/t -tinj - nT'])
set_param([sys,'/','Subsystem/t -tinj - nT'],...
		'position',[500,225,505,230])

add_block('built-in/Derivative',[sys,'/',['Subsystem/Drive de',13,'B relle']])
set_param([sys,'/',['Subsystem/Drive de',13,'B relle']],...
		'position',[230,262,285,298])

add_block('built-in/Note',[sys,'/','Subsystem/derb_chapeau'])
set_param([sys,'/','Subsystem/derb_chapeau'],...
		'position',[535,335,540,340])

add_block('built-in/Note',[sys,'/','Subsystem/Drive B'])
set_param([sys,'/','Subsystem/Drive B'],...
		'position',[495,270,500,275])


%     Subsystem  'Subsystem/CHAMP MESURE'.

new_system([sys,'/','Subsystem/CHAMP MESURE'])
set_param([sys,'/','Subsystem/CHAMP MESURE'],'Location',[198,215,1097,749])

add_block('built-in/Note',[sys,'/',['Subsystem/CHAMP MESURE/MESURE ECHANTILLONEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta//2']])
set_param([sys,'/',['Subsystem/CHAMP MESURE/MESURE ECHANTILLONEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta//2']],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[360,5,365,10])

add_block('built-in/Note',[sys,'/','Subsystem/CHAMP MESURE/t-nT'])
set_param([sys,'/','Subsystem/CHAMP MESURE/t-nT'],...
		'position',[930,355,935,360])

add_block('built-in/To Workspace',[sys,'/','Subsystem/CHAMP MESURE/To Workspace4'])
set_param([sys,'/','Subsystem/CHAMP MESURE/To Workspace4'],...
		'mat-name','temps',...
		'buffer','20000',...
		'position',[140,412,190,428])

add_block('built-in/Clock',[sys,'/','Subsystem/CHAMP MESURE/Clock2'])
set_param([sys,'/','Subsystem/CHAMP MESURE/Clock2'],...
		'hide name',0,...
		'position',[45,330,85,370])


%     Subsystem  'Subsystem/CHAMP MESURE/Subsystem'.

new_system([sys,'/','Subsystem/CHAMP MESURE/Subsystem'])
set_param([sys,'/','Subsystem/CHAMP MESURE/Subsystem'],'Location',[163,376,803,621])

add_block('built-in/Inport',[sys,'/','Subsystem/CHAMP MESURE/Subsystem/in_1'])
set_param([sys,'/','Subsystem/CHAMP MESURE/Subsystem/in_1'],...
		'position',[245,115,265,135])

add_block('built-in/Note',[sys,'/','Subsystem/CHAMP MESURE/Subsystem/Calcul t-nT1'])
set_param([sys,'/','Subsystem/CHAMP MESURE/Subsystem/Calcul t-nT1'],...
		'hide name',0,...
		'position',[460,206,465,211])

add_block('built-in/Constant',[sys,'/','Subsystem/CHAMP MESURE/Subsystem/Constant4'])
set_param([sys,'/','Subsystem/CHAMP MESURE/Subsystem/Constant4'],...
		'hide name',0,...
		'Value','instant_injection',...
		'position',[165,154,270,176])

add_block('built-in/Sum',[sys,'/','Subsystem/CHAMP MESURE/Subsystem/Sum4'])
set_param([sys,'/','Subsystem/CHAMP MESURE/Subsystem/Sum4'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[295,107,320,183])

add_block('built-in/MATLAB Fcn',[sys,'/',['Subsystem/CHAMP MESURE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T']])
set_param([sys,'/',['Subsystem/CHAMP MESURE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T']],...
		'MATLAB Fcn','fix(u/T)*T',...
		'Output Width','1',...
		'position',[365,128,425,162])

add_block('built-in/Sum',[sys,'/','Subsystem/CHAMP MESURE/Subsystem/Sum1'])
set_param([sys,'/','Subsystem/CHAMP MESURE/Subsystem/Sum1'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[475,54,495,176])

add_block('built-in/Note',[sys,'/',['Subsystem/CHAMP MESURE/Subsystem/Le temps courant de la simulation',13,'commence  l''instant d''injection ']])
set_param([sys,'/',['Subsystem/CHAMP MESURE/Subsystem/Le temps courant de la simulation',13,'commence  l''instant d''injection ']],...
		'Font Name','Arial',...
		'position',[135,100,140,105])

add_block('built-in/Note',[sys,'/',['Subsystem/CHAMP MESURE/Subsystem/CALCUL DE LA PARTIE FRACTIONNAIRE',13,'DE LA PERIODE ENTRE nT ET (n+1)T']])
set_param([sys,'/',['Subsystem/CHAMP MESURE/Subsystem/CALCUL DE LA PARTIE FRACTIONNAIRE',13,'DE LA PERIODE ENTRE nT ET (n+1)T']],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12)
set_param([sys,'/',['Subsystem/CHAMP MESURE/Subsystem/CALCUL DE LA PARTIE FRACTIONNAIRE',13,'DE LA PERIODE ENTRE nT ET (n+1)T']],...
		'position',[315,0,320,5])

add_block('built-in/Outport',[sys,'/','Subsystem/CHAMP MESURE/Subsystem/out_1'])
set_param([sys,'/','Subsystem/CHAMP MESURE/Subsystem/out_1'],...
		'position',[555,105,575,125])
add_line([sys,'/','Subsystem/CHAMP MESURE/Subsystem'],[270,125;290,125])
add_line([sys,'/','Subsystem/CHAMP MESURE/Subsystem'],[500,115;550,115])
add_line([sys,'/','Subsystem/CHAMP MESURE/Subsystem'],[430,145;470,145])
add_line([sys,'/','Subsystem/CHAMP MESURE/Subsystem'],[275,165;290,165])
add_line([sys,'/','Subsystem/CHAMP MESURE/Subsystem'],[325,145;360,145])
add_line([sys,'/','Subsystem/CHAMP MESURE/Subsystem'],[345,145;345,85;470,85])
set_param([sys,'/','Subsystem/CHAMP MESURE/Subsystem'],...
		'Mask Display','Mise en place\ndes priodes')


%     Finished composite block 'Subsystem/CHAMP MESURE/Subsystem'.

set_param([sys,'/','Subsystem/CHAMP MESURE/Subsystem'],...
		'hide name',0,...
		'position',[115,326,255,374])

add_block('built-in/Note',[sys,'/',['Subsystem/CHAMP MESURE/Temps courant',13,'de la simulation']])
set_param([sys,'/',['Subsystem/CHAMP MESURE/Temps courant',13,'de la simulation']],...
		'position',[75,280,80,285])

add_block('built-in/Note',[sys,'/','Subsystem/CHAMP MESURE/Sortie de to = t -tinj - nT'])
set_param([sys,'/','Subsystem/CHAMP MESURE/Sortie de to = t -tinj - nT'],...
		'position',[585,385,590,390])

add_block('built-in/Constant',[sys,'/','Subsystem/CHAMP MESURE/Constant1'])
set_param([sys,'/','Subsystem/CHAMP MESURE/Constant1'],...
		'hide name',0,...
		'Value','Ta/2',...
		'position',[305,279,340,301])

add_block('built-in/Relational Operator',[sys,'/',['Subsystem/CHAMP MESURE/Relational',13,'Operator']])
set_param([sys,'/',['Subsystem/CHAMP MESURE/Relational',13,'Operator']],...
		'hide name',0,...
		'position',[375,258,400,382])

add_block('built-in/To Workspace',[sys,'/','Subsystem/CHAMP MESURE/To Workspace3'])
set_param([sys,'/','Subsystem/CHAMP MESURE/To Workspace3'],...
		'mat-name','champ1',...
		'buffer','20000',...
		'position',[610,272,660,288])

add_block('built-in/Outport',[sys,'/','Subsystem/CHAMP MESURE/out_2'])
set_param([sys,'/','Subsystem/CHAMP MESURE/out_2'],...
		'Port','3',...
		'position',[615,420,635,440])

add_block('built-in/MATLAB Fcn',[sys,'/',['Subsystem/CHAMP MESURE/Partie',13,'entire n1']])
set_param([sys,'/',['Subsystem/CHAMP MESURE/Partie',13,'entire n1']],...
		'hide name',0,...
		'MATLAB Fcn','storcham(u)',...
		'Output Width','3',...
		'position',[505,213,565,247])

add_block('built-in/Mux',[sys,'/','Subsystem/CHAMP MESURE/Mux1'])
set_param([sys,'/','Subsystem/CHAMP MESURE/Mux1'],...
		'inputs','[3 1]',...
		'position',[445,211,475,244])

add_block('built-in/Note',[sys,'/',['Subsystem/CHAMP MESURE/Entre du champ en axes satellite ',13,' l''instant t de la simulation',13,'']])
set_param([sys,'/',['Subsystem/CHAMP MESURE/Entre du champ en axes satellite ',13,' l''instant t de la simulation',13,'']],...
		'position',[215,200,220,205])

add_block('built-in/Note',[sys,'/','Subsystem/CHAMP MESURE/t - tinj- nT'])
set_param([sys,'/','Subsystem/CHAMP MESURE/t - tinj- nT'],...
		'position',[335,350,340,355])

add_block('built-in/Note',[sys,'/','Subsystem/CHAMP MESURE/Sortie champ B chapeau'])
set_param([sys,'/','Subsystem/CHAMP MESURE/Sortie champ B chapeau'],...
		'position',[620,180,625,185])

add_block('built-in/Note',[sys,'/','Subsystem/CHAMP MESURE/Calcul t-nT'])
set_param([sys,'/','Subsystem/CHAMP MESURE/Calcul t-nT'],...
		'hide name',0,...
		'position',[265,430,270,435])

add_block('built-in/Note',[sys,'/','Subsystem/CHAMP MESURE/Entre de B(t) //xyz '])
set_param([sys,'/','Subsystem/CHAMP MESURE/Entre de B(t) //xyz '],...
		'position',[115,180,120,185])

add_block('built-in/Inport',[sys,'/','Subsystem/CHAMP MESURE/in_1'])
set_param([sys,'/','Subsystem/CHAMP MESURE/in_1'],...
		'position',[65,210,85,230])

add_block('built-in/Outport',[sys,'/','Subsystem/CHAMP MESURE/out_3'])
set_param([sys,'/','Subsystem/CHAMP MESURE/out_3'],...
		'position',[615,100,635,120])

add_block('built-in/Outport',[sys,'/','Subsystem/CHAMP MESURE/out_1'])
set_param([sys,'/','Subsystem/CHAMP MESURE/out_1'],...
		'Port','2',...
		'position',[615,220,635,240])
add_line([sys,'/','Subsystem/CHAMP MESURE'],[260,350;285,350;285,430;610,430])
add_line([sys,'/','Subsystem/CHAMP MESURE'],[285,350;370,350])
add_line([sys,'/','Subsystem/CHAMP MESURE'],[90,220;440,220])
add_line([sys,'/','Subsystem/CHAMP MESURE'],[480,230;500,230])
add_line([sys,'/','Subsystem/CHAMP MESURE'],[570,230;610,230])
add_line([sys,'/','Subsystem/CHAMP MESURE'],[405,320;430,320;440,235])
add_line([sys,'/','Subsystem/CHAMP MESURE'],[590,230;590,280;605,280])
add_line([sys,'/','Subsystem/CHAMP MESURE'],[345,290;370,290])
add_line([sys,'/','Subsystem/CHAMP MESURE'],[90,350;110,350])
add_line([sys,'/','Subsystem/CHAMP MESURE'],[90,350;90,420;135,420])
add_line([sys,'/','Subsystem/CHAMP MESURE'],[390,220;390,110;610,110])
set_param([sys,'/','Subsystem/CHAMP MESURE'],...
		'Mask Display','CHAMP MESURE\n\n periode n')


%     Finished composite block 'Subsystem/CHAMP MESURE'.

set_param([sys,'/','Subsystem/CHAMP MESURE'],...
		'position',[300,165,435,235])

add_block('built-in/Product',[sys,'/','Subsystem/Product'])
set_param([sys,'/','Subsystem/Product'],...
		'position',[535,227,560,323])

add_block('built-in/Note',[sys,'/','Subsystem/Calcul t-nT'])
set_param([sys,'/','Subsystem/Calcul t-nT'],...
		'hide name',0,...
		'position',[410,385,415,390])


%     Subsystem  'Subsystem/DERIVEE MESUREE'.

new_system([sys,'/','Subsystem/DERIVEE MESUREE'])
set_param([sys,'/','Subsystem/DERIVEE MESUREE'],'Location',[4,50,853,441])

add_block('built-in/Note',[sys,'/',['Subsystem/DERIVEE MESUREE/derb_chapeau est la valeur constante conserve aprs la mesure',13,'']])
set_param([sys,'/',['Subsystem/DERIVEE MESUREE/derb_chapeau est la valeur constante conserve aprs la mesure',13,'']],...
		'ForeGround',3,...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[420,45,425,50])

add_block('built-in/Note',[sys,'/','Subsystem/DERIVEE MESUREE/derb_lin est la valeur linarise conserve aprs la mesure'])
set_param([sys,'/','Subsystem/DERIVEE MESUREE/derb_lin est la valeur linarise conserve aprs la mesure'],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[405,75,410,80])

add_block('built-in/Note',[sys,'/',['Subsystem/DERIVEE MESUREE/MESURE ECHANTILLONEE DE LA DERIVEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta']])
set_param([sys,'/',['Subsystem/DERIVEE MESUREE/MESURE ECHANTILLONEE DE LA DERIVEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta']],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14)
set_param([sys,'/',['Subsystem/DERIVEE MESUREE/MESURE ECHANTILLONEE DE LA DERIVEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta']],...
		'position',[425,0,430,5])

add_block('built-in/Note',[sys,'/','Subsystem/DERIVEE MESUREE/Entre de dB//dt //xyz '])
set_param([sys,'/','Subsystem/DERIVEE MESUREE/Entre de dB//dt //xyz '],...
		'position',[355,115,360,120])

add_block('built-in/Note',[sys,'/','Subsystem/DERIVEE MESUREE/Sortie B_prime'])
set_param([sys,'/','Subsystem/DERIVEE MESUREE/Sortie B_prime'],...
		'position',[550,175,555,180])

add_block('built-in/Mux',[sys,'/','Subsystem/DERIVEE MESUREE/Mux1'])
set_param([sys,'/','Subsystem/DERIVEE MESUREE/Mux1'],...
		'inputs','[3 1]',...
		'position',[455,206,485,239])

add_block('built-in/Note',[sys,'/','Subsystem/DERIVEE MESUREE/t--tinj -nT'])
set_param([sys,'/','Subsystem/DERIVEE MESUREE/t--tinj -nT'],...
		'position',[335,235,340,240])

add_block('built-in/Relational Operator',[sys,'/',['Subsystem/DERIVEE MESUREE/Relational',13,'Operator']])
set_param([sys,'/',['Subsystem/DERIVEE MESUREE/Relational',13,'Operator']],...
		'hide name',0,...
		'position',[375,168,400,292])

add_block('built-in/Constant',[sys,'/','Subsystem/DERIVEE MESUREE/Constant1'])
set_param([sys,'/','Subsystem/DERIVEE MESUREE/Constant1'],...
		'hide name',0,...
		'Value','Ta/2',...
		'position',[325,189,360,211])

add_block('built-in/To Workspace',[sys,'/','Subsystem/DERIVEE MESUREE/To Workspace5'])
set_param([sys,'/','Subsystem/DERIVEE MESUREE/To Workspace5'],...
		'hide name',0,...
		'mat-name','derb_chapeau',...
		'buffer','20000',...
		'position',[630,268,750,302])

add_block('built-in/Note',[sys,'/','Subsystem/DERIVEE MESUREE/t-tinj -nT<=Ta'])
set_param([sys,'/','Subsystem/DERIVEE MESUREE/t-tinj -nT<=Ta'],...
		'position',[390,290,395,295])

add_block('built-in/Inport',[sys,'/','Subsystem/DERIVEE MESUREE/in_1'])
set_param([sys,'/','Subsystem/DERIVEE MESUREE/in_1'],...
		'position',[105,135,125,155])

add_block('built-in/MATLAB Fcn',[sys,'/',['Subsystem/DERIVEE MESUREE/Partie',13,'entire n1']])
set_param([sys,'/',['Subsystem/DERIVEE MESUREE/Partie',13,'entire n1']],...
		'hide name',0,...
		'MATLAB Fcn','storderB(u)',...
		'Output Width','3',...
		'position',[515,208,575,242])

add_block('built-in/To File',[sys,'/','Subsystem/DERIVEE MESUREE/To File'])
set_param([sys,'/','Subsystem/DERIVEE MESUREE/To File'],...
		'File name','derbchap.mat',...
		'Matrix name','derb_chapeau',...
		'position',[635,134,730,166])

add_block('built-in/Outport',[sys,'/','Subsystem/DERIVEE MESUREE/out_1'])
set_param([sys,'/','Subsystem/DERIVEE MESUREE/out_1'],...
		'position',[715,215,735,235])

add_block('built-in/Note',[sys,'/','Subsystem/DERIVEE MESUREE/Sortie de t-tinj-nT'])
set_param([sys,'/','Subsystem/DERIVEE MESUREE/Sortie de t-tinj-nT'],...
		'position',[395,310,400,315])

add_block('built-in/Note',[sys,'/','Subsystem/DERIVEE MESUREE/B(n)'])
set_param([sys,'/','Subsystem/DERIVEE MESUREE/B(n)'],...
		'position',[620,196,625,201])

add_block('built-in/Note',[sys,'/','Subsystem/DERIVEE MESUREE/derb_chapeau'])
set_param([sys,'/','Subsystem/DERIVEE MESUREE/derb_chapeau'],...
		'position',[785,211,790,216])

add_block('built-in/To Workspace',[sys,'/','Subsystem/DERIVEE MESUREE/To Workspace7'])
set_param([sys,'/','Subsystem/DERIVEE MESUREE/To Workspace7'],...
		'hide name',0,...
		'mat-name','der_seconde',...
		'buffer','20000',...
		'position',[705,568,825,602])


%     Subsystem  'Subsystem/DERIVEE MESUREE/Subsystem'.

new_system([sys,'/','Subsystem/DERIVEE MESUREE/Subsystem'])
set_param([sys,'/','Subsystem/DERIVEE MESUREE/Subsystem'],'Location',[125,1114771,765,1115016])

add_block('built-in/Inport',[sys,'/','Subsystem/DERIVEE MESUREE/Subsystem/in_1'])
set_param([sys,'/','Subsystem/DERIVEE MESUREE/Subsystem/in_1'],...
		'position',[245,115,265,135])

add_block('built-in/Outport',[sys,'/','Subsystem/DERIVEE MESUREE/Subsystem/out_1'])
set_param([sys,'/','Subsystem/DERIVEE MESUREE/Subsystem/out_1'],...
		'position',[525,105,545,125])

add_block('built-in/Note',[sys,'/','Subsystem/DERIVEE MESUREE/Subsystem/Calcul t-nT1'])
set_param([sys,'/','Subsystem/DERIVEE MESUREE/Subsystem/Calcul t-nT1'],...
		'hide name',0,...
		'position',[460,206,465,211])

add_block('built-in/Constant',[sys,'/','Subsystem/DERIVEE MESUREE/Subsystem/Constant4'])
set_param([sys,'/','Subsystem/DERIVEE MESUREE/Subsystem/Constant4'],...
		'hide name',0,...
		'Value','instant_injection',...
		'position',[165,154,270,176])

add_block('built-in/Sum',[sys,'/','Subsystem/DERIVEE MESUREE/Subsystem/Sum4'])
set_param([sys,'/','Subsystem/DERIVEE MESUREE/Subsystem/Sum4'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[295,107,320,183])

add_block('built-in/MATLAB Fcn',[sys,'/',['Subsystem/DERIVEE MESUREE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T2']])
set_param([sys,'/',['Subsystem/DERIVEE MESUREE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T2']],...
		'MATLAB Fcn','fix(u/T)*T',...
		'Output Width','1',...
		'position',[365,128,425,162])

add_block('built-in/Sum',[sys,'/','Subsystem/DERIVEE MESUREE/Subsystem/Sum1'])
set_param([sys,'/','Subsystem/DERIVEE MESUREE/Subsystem/Sum1'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[475,54,495,176])

add_block('built-in/Note',[sys,'/',['Subsystem/DERIVEE MESUREE/Subsystem/Le temps courant de la simulation',13,'commence  l''instant d''injection ']])
set_param([sys,'/',['Subsystem/DERIVEE MESUREE/Subsystem/Le temps courant de la simulation',13,'commence  l''instant d''injection ']],...
		'Font Name','Arial',...
		'position',[175,70,180,75])
add_line([sys,'/','Subsystem/DERIVEE MESUREE/Subsystem'],[270,125;290,125])
add_line([sys,'/','Subsystem/DERIVEE MESUREE/Subsystem'],[500,115;520,115])
add_line([sys,'/','Subsystem/DERIVEE MESUREE/Subsystem'],[430,145;470,145])
add_line([sys,'/','Subsystem/DERIVEE MESUREE/Subsystem'],[275,165;290,165])
add_line([sys,'/','Subsystem/DERIVEE MESUREE/Subsystem'],[325,145;360,145])
add_line([sys,'/','Subsystem/DERIVEE MESUREE/Subsystem'],[345,145;345,85;470,85])
set_param([sys,'/','Subsystem/DERIVEE MESUREE/Subsystem'],...
		'Mask Display','Mise en place\ndes priodes')


%     Finished composite block 'Subsystem/DERIVEE MESUREE/Subsystem'.

set_param([sys,'/','Subsystem/DERIVEE MESUREE/Subsystem'],...
		'hide name',0,...
		'position',[155,236,295,284])

add_block('built-in/Note',[sys,'/',['Subsystem/DERIVEE MESUREE/Temps courant',13,'de la simulation']])
set_param([sys,'/',['Subsystem/DERIVEE MESUREE/Temps courant',13,'de la simulation']],...
		'position',[70,295,75,300])

add_block('built-in/Inport',[sys,'/','Subsystem/DERIVEE MESUREE/in_2'])
set_param([sys,'/','Subsystem/DERIVEE MESUREE/in_2'],...
		'Port','2',...
		'position',[95,250,115,270])
add_line([sys,'/','Subsystem/DERIVEE MESUREE'],[300,260;370,260])
add_line([sys,'/','Subsystem/DERIVEE MESUREE'],[130,145;430,145;430,215;450,215])
add_line([sys,'/','Subsystem/DERIVEE MESUREE'],[365,200;370,200])
add_line([sys,'/','Subsystem/DERIVEE MESUREE'],[405,230;450,230])
add_line([sys,'/','Subsystem/DERIVEE MESUREE'],[490,225;510,225])
add_line([sys,'/','Subsystem/DERIVEE MESUREE'],[580,225;710,225])
add_line([sys,'/','Subsystem/DERIVEE MESUREE'],[595,225;595,285;625,285])
add_line([sys,'/','Subsystem/DERIVEE MESUREE'],[595,225;595,150;630,150])
add_line([sys,'/','Subsystem/DERIVEE MESUREE'],[120,260;150,260])
set_param([sys,'/','Subsystem/DERIVEE MESUREE'],...
		'Mask Display','DERIVEE DE B\n\nMESUREE\n\nPERIODE n')


%     Finished composite block 'Subsystem/DERIVEE MESUREE'.

set_param([sys,'/','Subsystem/DERIVEE MESUREE'],...
		'position',[310,260,445,340])

add_block('built-in/Sum',[sys,'/','Subsystem/Sum'])
set_param([sys,'/','Subsystem/Sum'],...
		'hide name',0,...
		'position',[640,134,665,321])

add_block('built-in/Outport',[sys,'/','Subsystem/out_2'])
set_param([sys,'/','Subsystem/out_2'],...
		'Port','2',...
		'position',[790,145,810,165])

add_block('built-in/Outport',[sys,'/','Subsystem/out_1'])
set_param([sys,'/','Subsystem/out_1'],...
		'position',[780,45,800,65])

add_block('built-in/Outport',[sys,'/','Subsystem/out_3'])
set_param([sys,'/','Subsystem/out_3'],...
		'Port','3',...
		'position',[800,390,820,410])

add_block('built-in/Note',[sys,'/','Subsystem/Drive pulse non lisse'])
set_param([sys,'/','Subsystem/Drive pulse non lisse'],...
		'position',[790,425,795,430])

add_block('built-in/Note',[sys,'/','Subsystem/Champ  liss'])
set_param([sys,'/','Subsystem/Champ  liss'],...
		'position',[775,115,780,120])

add_block('built-in/Note',[sys,'/','Subsystem/Champ rel satellite'])
set_param([sys,'/','Subsystem/Champ rel satellite'],...
		'position',[690,55,695,60])

add_block('built-in/Inport',[sys,'/','Subsystem/in_2'])
set_param([sys,'/','Subsystem/in_2'],...
		'Port','2',...
		'position',[120,310,140,330])

add_block('built-in/Inport',[sys,'/','Subsystem/in_1'])
set_param([sys,'/','Subsystem/in_1'],...
		'position',[115,190,135,210])
add_line([sys,'/','Subsystem'],[140,200;295,200])
add_line([sys,'/','Subsystem'],[275,200;190,200;190,280;225,280])
add_line([sys,'/','Subsystem'],[440,200;580,200;580,180;635,180])
add_line([sys,'/','Subsystem'],[440,225;455,225;455,250;530,250])
add_line([sys,'/','Subsystem'],[450,300;530,300])
add_line([sys,'/','Subsystem'],[670,230;725,230])
add_line([sys,'/','Subsystem'],[565,275;635,275])
add_line([sys,'/','Subsystem'],[290,280;305,280])
add_line([sys,'/','Subsystem'],[145,320;305,320])
add_line([sys,'/','Subsystem'],[440,175;465,175;465,55;775,55])
add_line([sys,'/','Subsystem'],[475,300;475,400;795,400])
add_line([sys,'/','Subsystem'],[685,230;685,155;785,155])
set_param([sys,'/','Subsystem'],...
		'Mask Display','Champ rel\n&\nchamp mesur',...
		'Mask Help','Entre 1= champ satellite, entre 2=temps, sortie 1= champ satellite, sortie2= champ liss, sortie 3 = drive non lisse')


%     Finished composite block 'Subsystem'.

set_param([sys,'/','Subsystem'],...
		'hide name',0,...
		'position',[40,31,165,109])


%     Subsystem  'Subsystem1'.

new_system([sys,'/','Subsystem1'])
set_param([sys,'/','Subsystem1'],'Location',[262,60,1207,525])

add_block('built-in/Note',[sys,'/','Subsystem1/Temps'])
set_param([sys,'/','Subsystem1/Temps'],...
		'position',[130,285,135,290])

add_block('built-in/Note',[sys,'/',['Subsystem1/Champ magntique',13,'terrestre',13,'(repre satellite)']])
set_param([sys,'/',['Subsystem1/Champ magntique',13,'terrestre',13,'(repre satellite)']],...
		'position',[130,120,135,125])

add_block('built-in/To Workspace',[sys,'/','Subsystem1/To Workspace5'])
set_param([sys,'/','Subsystem1/To Workspace5'],...
		'hide name',0,...
		'mat-name','champ_pulse',...
		'buffer','20000',...
		'position',[730,213,850,247])

add_block('built-in/Note',[sys,'/','Subsystem1/B(n)'])
set_param([sys,'/','Subsystem1/B(n)'],...
		'position',[535,175,540,180])

add_block('built-in/Note',[sys,'/','Subsystem1/t -tinj - nT'])
set_param([sys,'/','Subsystem1/t -tinj - nT'],...
		'position',[500,225,505,230])

add_block('built-in/Derivative',[sys,'/',['Subsystem1/Drive de',13,'B relle']])
set_param([sys,'/',['Subsystem1/Drive de',13,'B relle']],...
		'position',[230,262,285,298])

add_block('built-in/Note',[sys,'/','Subsystem1/derb_chapeau'])
set_param([sys,'/','Subsystem1/derb_chapeau'],...
		'position',[535,335,540,340])

add_block('built-in/Note',[sys,'/','Subsystem1/Drive B'])
set_param([sys,'/','Subsystem1/Drive B'],...
		'position',[495,270,500,275])


%     Subsystem  'Subsystem1/CHAMP MESURE'.

new_system([sys,'/','Subsystem1/CHAMP MESURE'])
set_param([sys,'/','Subsystem1/CHAMP MESURE'],'Location',[198,215,1097,749])

add_block('built-in/Note',[sys,'/',['Subsystem1/CHAMP MESURE/MESURE ECHANTILLONEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta//2']])
set_param([sys,'/',['Subsystem1/CHAMP MESURE/MESURE ECHANTILLONEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta//2']],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[360,5,365,10])

add_block('built-in/Note',[sys,'/','Subsystem1/CHAMP MESURE/t-nT'])
set_param([sys,'/','Subsystem1/CHAMP MESURE/t-nT'],...
		'position',[930,355,935,360])

add_block('built-in/To Workspace',[sys,'/','Subsystem1/CHAMP MESURE/To Workspace4'])
set_param([sys,'/','Subsystem1/CHAMP MESURE/To Workspace4'],...
		'mat-name','temps',...
		'buffer','20000',...
		'position',[140,412,190,428])

add_block('built-in/Clock',[sys,'/','Subsystem1/CHAMP MESURE/Clock2'])
set_param([sys,'/','Subsystem1/CHAMP MESURE/Clock2'],...
		'hide name',0,...
		'position',[45,330,85,370])


%     Subsystem  'Subsystem1/CHAMP MESURE/Subsystem'.

new_system([sys,'/','Subsystem1/CHAMP MESURE/Subsystem'])
set_param([sys,'/','Subsystem1/CHAMP MESURE/Subsystem'],'Location',[163,376,803,621])

add_block('built-in/Inport',[sys,'/','Subsystem1/CHAMP MESURE/Subsystem/in_1'])
set_param([sys,'/','Subsystem1/CHAMP MESURE/Subsystem/in_1'],...
		'position',[245,115,265,135])

add_block('built-in/Note',[sys,'/','Subsystem1/CHAMP MESURE/Subsystem/Calcul t-nT1'])
set_param([sys,'/','Subsystem1/CHAMP MESURE/Subsystem/Calcul t-nT1'],...
		'hide name',0,...
		'position',[460,206,465,211])

add_block('built-in/Constant',[sys,'/','Subsystem1/CHAMP MESURE/Subsystem/Constant4'])
set_param([sys,'/','Subsystem1/CHAMP MESURE/Subsystem/Constant4'],...
		'hide name',0,...
		'Value','instant_injection',...
		'position',[165,154,270,176])

add_block('built-in/Sum',[sys,'/','Subsystem1/CHAMP MESURE/Subsystem/Sum4'])
set_param([sys,'/','Subsystem1/CHAMP MESURE/Subsystem/Sum4'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[295,107,320,183])

add_block('built-in/MATLAB Fcn',[sys,'/',['Subsystem1/CHAMP MESURE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T']])
set_param([sys,'/',['Subsystem1/CHAMP MESURE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T']],...
		'MATLAB Fcn','fix(u/T)*T',...
		'Output Width','1',...
		'position',[365,128,425,162])

add_block('built-in/Sum',[sys,'/','Subsystem1/CHAMP MESURE/Subsystem/Sum1'])
set_param([sys,'/','Subsystem1/CHAMP MESURE/Subsystem/Sum1'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[475,54,495,176])

add_block('built-in/Note',[sys,'/',['Subsystem1/CHAMP MESURE/Subsystem/Le temps courant de la simulation',13,'commence  l''instant d''injection ']])
set_param([sys,'/',['Subsystem1/CHAMP MESURE/Subsystem/Le temps courant de la simulation',13,'commence  l''instant d''injection ']],...
		'Font Name','Arial',...
		'position',[135,100,140,105])

add_block('built-in/Note',[sys,'/',['Subsystem1/CHAMP MESURE/Subsystem/CALCUL DE LA PARTIE FRACTIONNAIRE',13,'DE LA PERIODE ENTRE nT ET (n+1)T']])
set_param([sys,'/',['Subsystem1/CHAMP MESURE/Subsystem/CALCUL DE LA PARTIE FRACTIONNAIRE',13,'DE LA PERIODE ENTRE nT ET (n+1)T']],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12)
set_param([sys,'/',['Subsystem1/CHAMP MESURE/Subsystem/CALCUL DE LA PARTIE FRACTIONNAIRE',13,'DE LA PERIODE ENTRE nT ET (n+1)T']],...
		'position',[315,0,320,5])

add_block('built-in/Outport',[sys,'/','Subsystem1/CHAMP MESURE/Subsystem/out_1'])
set_param([sys,'/','Subsystem1/CHAMP MESURE/Subsystem/out_1'],...
		'position',[555,105,575,125])
add_line([sys,'/','Subsystem1/CHAMP MESURE/Subsystem'],[270,125;290,125])
add_line([sys,'/','Subsystem1/CHAMP MESURE/Subsystem'],[500,115;550,115])
add_line([sys,'/','Subsystem1/CHAMP MESURE/Subsystem'],[430,145;470,145])
add_line([sys,'/','Subsystem1/CHAMP MESURE/Subsystem'],[275,165;290,165])
add_line([sys,'/','Subsystem1/CHAMP MESURE/Subsystem'],[325,145;360,145])
add_line([sys,'/','Subsystem1/CHAMP MESURE/Subsystem'],[345,145;345,85;470,85])
set_param([sys,'/','Subsystem1/CHAMP MESURE/Subsystem'],...
		'Mask Display','Mise en place\ndes priodes')


%     Finished composite block 'Subsystem1/CHAMP MESURE/Subsystem'.

set_param([sys,'/','Subsystem1/CHAMP MESURE/Subsystem'],...
		'hide name',0,...
		'position',[115,326,255,374])

add_block('built-in/Note',[sys,'/',['Subsystem1/CHAMP MESURE/Temps courant',13,'de la simulation']])
set_param([sys,'/',['Subsystem1/CHAMP MESURE/Temps courant',13,'de la simulation']],...
		'position',[75,280,80,285])

add_block('built-in/Note',[sys,'/','Subsystem1/CHAMP MESURE/Sortie de to = t -tinj - nT'])
set_param([sys,'/','Subsystem1/CHAMP MESURE/Sortie de to = t -tinj - nT'],...
		'position',[585,385,590,390])

add_block('built-in/Constant',[sys,'/','Subsystem1/CHAMP MESURE/Constant1'])
set_param([sys,'/','Subsystem1/CHAMP MESURE/Constant1'],...
		'hide name',0,...
		'Value','Ta/2',...
		'position',[305,279,340,301])

add_block('built-in/Relational Operator',[sys,'/',['Subsystem1/CHAMP MESURE/Relational',13,'Operator']])
set_param([sys,'/',['Subsystem1/CHAMP MESURE/Relational',13,'Operator']],...
		'hide name',0,...
		'position',[375,258,400,382])

add_block('built-in/To Workspace',[sys,'/','Subsystem1/CHAMP MESURE/To Workspace3'])
set_param([sys,'/','Subsystem1/CHAMP MESURE/To Workspace3'],...
		'mat-name','champ1',...
		'buffer','20000',...
		'position',[610,272,660,288])

add_block('built-in/Outport',[sys,'/','Subsystem1/CHAMP MESURE/out_2'])
set_param([sys,'/','Subsystem1/CHAMP MESURE/out_2'],...
		'Port','3',...
		'position',[615,420,635,440])

add_block('built-in/MATLAB Fcn',[sys,'/',['Subsystem1/CHAMP MESURE/Partie',13,'entire n1']])
set_param([sys,'/',['Subsystem1/CHAMP MESURE/Partie',13,'entire n1']],...
		'hide name',0,...
		'MATLAB Fcn','storcham(u)',...
		'Output Width','3',...
		'position',[505,213,565,247])

add_block('built-in/Mux',[sys,'/','Subsystem1/CHAMP MESURE/Mux1'])
set_param([sys,'/','Subsystem1/CHAMP MESURE/Mux1'],...
		'inputs','[3 1]',...
		'position',[445,211,475,244])

add_block('built-in/Note',[sys,'/',['Subsystem1/CHAMP MESURE/Entre du champ en axes satellite ',13,' l''instant t de la simulation',13,'']])
set_param([sys,'/',['Subsystem1/CHAMP MESURE/Entre du champ en axes satellite ',13,' l''instant t de la simulation',13,'']],...
		'position',[215,200,220,205])

add_block('built-in/Note',[sys,'/','Subsystem1/CHAMP MESURE/t - tinj- nT'])
set_param([sys,'/','Subsystem1/CHAMP MESURE/t - tinj- nT'],...
		'position',[335,350,340,355])

add_block('built-in/Note',[sys,'/','Subsystem1/CHAMP MESURE/Sortie champ B chapeau'])
set_param([sys,'/','Subsystem1/CHAMP MESURE/Sortie champ B chapeau'],...
		'position',[620,180,625,185])

add_block('built-in/Note',[sys,'/','Subsystem1/CHAMP MESURE/Calcul t-nT'])
set_param([sys,'/','Subsystem1/CHAMP MESURE/Calcul t-nT'],...
		'hide name',0,...
		'position',[265,430,270,435])

add_block('built-in/Note',[sys,'/','Subsystem1/CHAMP MESURE/Entre de B(t) //xyz '])
set_param([sys,'/','Subsystem1/CHAMP MESURE/Entre de B(t) //xyz '],...
		'position',[115,180,120,185])

add_block('built-in/Inport',[sys,'/','Subsystem1/CHAMP MESURE/in_1'])
set_param([sys,'/','Subsystem1/CHAMP MESURE/in_1'],...
		'position',[65,210,85,230])

add_block('built-in/Outport',[sys,'/','Subsystem1/CHAMP MESURE/out_3'])
set_param([sys,'/','Subsystem1/CHAMP MESURE/out_3'],...
		'position',[615,100,635,120])

add_block('built-in/Outport',[sys,'/','Subsystem1/CHAMP MESURE/out_1'])
set_param([sys,'/','Subsystem1/CHAMP MESURE/out_1'],...
		'Port','2',...
		'position',[615,220,635,240])
add_line([sys,'/','Subsystem1/CHAMP MESURE'],[260,350;285,350;285,430;610,430])
add_line([sys,'/','Subsystem1/CHAMP MESURE'],[285,350;370,350])
add_line([sys,'/','Subsystem1/CHAMP MESURE'],[90,220;440,220])
add_line([sys,'/','Subsystem1/CHAMP MESURE'],[480,230;500,230])
add_line([sys,'/','Subsystem1/CHAMP MESURE'],[570,230;610,230])
add_line([sys,'/','Subsystem1/CHAMP MESURE'],[405,320;430,320;440,235])
add_line([sys,'/','Subsystem1/CHAMP MESURE'],[590,230;590,280;605,280])
add_line([sys,'/','Subsystem1/CHAMP MESURE'],[345,290;370,290])
add_line([sys,'/','Subsystem1/CHAMP MESURE'],[90,350;110,350])
add_line([sys,'/','Subsystem1/CHAMP MESURE'],[90,350;90,420;135,420])
add_line([sys,'/','Subsystem1/CHAMP MESURE'],[390,220;390,110;610,110])
set_param([sys,'/','Subsystem1/CHAMP MESURE'],...
		'Mask Display','CHAMP MESURE\n\n periode n')


%     Finished composite block 'Subsystem1/CHAMP MESURE'.

set_param([sys,'/','Subsystem1/CHAMP MESURE'],...
		'position',[300,165,435,235])

add_block('built-in/Product',[sys,'/','Subsystem1/Product'])
set_param([sys,'/','Subsystem1/Product'],...
		'position',[535,227,560,323])

add_block('built-in/Note',[sys,'/','Subsystem1/Calcul t-nT'])
set_param([sys,'/','Subsystem1/Calcul t-nT'],...
		'hide name',0,...
		'position',[410,385,415,390])


%     Subsystem  'Subsystem1/DERIVEE MESUREE'.

new_system([sys,'/','Subsystem1/DERIVEE MESUREE'])
set_param([sys,'/','Subsystem1/DERIVEE MESUREE'],'Location',[4,50,853,441])

add_block('built-in/Note',[sys,'/',['Subsystem1/DERIVEE MESUREE/derb_chapeau est la valeur constante conserve aprs la mesure',13,'']])
set_param([sys,'/',['Subsystem1/DERIVEE MESUREE/derb_chapeau est la valeur constante conserve aprs la mesure',13,'']],...
		'ForeGround',3,...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[420,45,425,50])

add_block('built-in/Note',[sys,'/','Subsystem1/DERIVEE MESUREE/derb_lin est la valeur linarise conserve aprs la mesure'])
set_param([sys,'/','Subsystem1/DERIVEE MESUREE/derb_lin est la valeur linarise conserve aprs la mesure'],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[405,75,410,80])

add_block('built-in/Note',[sys,'/',['Subsystem1/DERIVEE MESUREE/MESURE ECHANTILLONEE DE LA DERIVEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta']])
set_param([sys,'/',['Subsystem1/DERIVEE MESUREE/MESURE ECHANTILLONEE DE LA DERIVEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta']],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14)
set_param([sys,'/',['Subsystem1/DERIVEE MESUREE/MESURE ECHANTILLONEE DE LA DERIVEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta']],...
		'position',[425,0,430,5])

add_block('built-in/Note',[sys,'/','Subsystem1/DERIVEE MESUREE/Entre de dB//dt //xyz '])
set_param([sys,'/','Subsystem1/DERIVEE MESUREE/Entre de dB//dt //xyz '],...
		'position',[355,115,360,120])

add_block('built-in/Note',[sys,'/','Subsystem1/DERIVEE MESUREE/Sortie B_prime'])
set_param([sys,'/','Subsystem1/DERIVEE MESUREE/Sortie B_prime'],...
		'position',[550,175,555,180])

add_block('built-in/Mux',[sys,'/','Subsystem1/DERIVEE MESUREE/Mux1'])
set_param([sys,'/','Subsystem1/DERIVEE MESUREE/Mux1'],...
		'inputs','[3 1]',...
		'position',[455,206,485,239])

add_block('built-in/Note',[sys,'/','Subsystem1/DERIVEE MESUREE/t--tinj -nT'])
set_param([sys,'/','Subsystem1/DERIVEE MESUREE/t--tinj -nT'],...
		'position',[335,235,340,240])

add_block('built-in/Relational Operator',[sys,'/',['Subsystem1/DERIVEE MESUREE/Relational',13,'Operator']])
set_param([sys,'/',['Subsystem1/DERIVEE MESUREE/Relational',13,'Operator']],...
		'hide name',0,...
		'position',[375,168,400,292])

add_block('built-in/Constant',[sys,'/','Subsystem1/DERIVEE MESUREE/Constant1'])
set_param([sys,'/','Subsystem1/DERIVEE MESUREE/Constant1'],...
		'hide name',0,...
		'Value','Ta/2',...
		'position',[325,189,360,211])

add_block('built-in/To Workspace',[sys,'/','Subsystem1/DERIVEE MESUREE/To Workspace5'])
set_param([sys,'/','Subsystem1/DERIVEE MESUREE/To Workspace5'],...
		'hide name',0,...
		'mat-name','derb_chapeau',...
		'buffer','20000',...
		'position',[630,268,750,302])

add_block('built-in/Note',[sys,'/','Subsystem1/DERIVEE MESUREE/t-tinj -nT<=Ta'])
set_param([sys,'/','Subsystem1/DERIVEE MESUREE/t-tinj -nT<=Ta'],...
		'position',[390,290,395,295])

add_block('built-in/Inport',[sys,'/','Subsystem1/DERIVEE MESUREE/in_1'])
set_param([sys,'/','Subsystem1/DERIVEE MESUREE/in_1'],...
		'position',[105,135,125,155])

add_block('built-in/MATLAB Fcn',[sys,'/',['Subsystem1/DERIVEE MESUREE/Partie',13,'entire n1']])
set_param([sys,'/',['Subsystem1/DERIVEE MESUREE/Partie',13,'entire n1']],...
		'hide name',0,...
		'MATLAB Fcn','storderB(u)',...
		'Output Width','3',...
		'position',[515,208,575,242])

add_block('built-in/To File',[sys,'/','Subsystem1/DERIVEE MESUREE/To File'])
set_param([sys,'/','Subsystem1/DERIVEE MESUREE/To File'],...
		'File name','derbchap.mat',...
		'Matrix name','derb_chapeau',...
		'position',[635,134,730,166])

add_block('built-in/Outport',[sys,'/','Subsystem1/DERIVEE MESUREE/out_1'])
set_param([sys,'/','Subsystem1/DERIVEE MESUREE/out_1'],...
		'position',[715,215,735,235])

add_block('built-in/Note',[sys,'/','Subsystem1/DERIVEE MESUREE/Sortie de t-tinj-nT'])
set_param([sys,'/','Subsystem1/DERIVEE MESUREE/Sortie de t-tinj-nT'],...
		'position',[395,310,400,315])

add_block('built-in/Note',[sys,'/','Subsystem1/DERIVEE MESUREE/B(n)'])
set_param([sys,'/','Subsystem1/DERIVEE MESUREE/B(n)'],...
		'position',[620,196,625,201])

add_block('built-in/Note',[sys,'/','Subsystem1/DERIVEE MESUREE/derb_chapeau'])
set_param([sys,'/','Subsystem1/DERIVEE MESUREE/derb_chapeau'],...
		'position',[785,211,790,216])

add_block('built-in/To Workspace',[sys,'/','Subsystem1/DERIVEE MESUREE/To Workspace7'])
set_param([sys,'/','Subsystem1/DERIVEE MESUREE/To Workspace7'],...
		'hide name',0,...
		'mat-name','der_seconde',...
		'buffer','20000',...
		'position',[705,568,825,602])


%     Subsystem  'Subsystem1/DERIVEE MESUREE/Subsystem'.

new_system([sys,'/','Subsystem1/DERIVEE MESUREE/Subsystem'])
set_param([sys,'/','Subsystem1/DERIVEE MESUREE/Subsystem'],'Location',[125,1114771,765,1115016])

add_block('built-in/Inport',[sys,'/','Subsystem1/DERIVEE MESUREE/Subsystem/in_1'])
set_param([sys,'/','Subsystem1/DERIVEE MESUREE/Subsystem/in_1'],...
		'position',[245,115,265,135])

add_block('built-in/Outport',[sys,'/','Subsystem1/DERIVEE MESUREE/Subsystem/out_1'])
set_param([sys,'/','Subsystem1/DERIVEE MESUREE/Subsystem/out_1'],...
		'position',[525,105,545,125])

add_block('built-in/Note',[sys,'/','Subsystem1/DERIVEE MESUREE/Subsystem/Calcul t-nT1'])
set_param([sys,'/','Subsystem1/DERIVEE MESUREE/Subsystem/Calcul t-nT1'],...
		'hide name',0,...
		'position',[460,206,465,211])

add_block('built-in/Constant',[sys,'/','Subsystem1/DERIVEE MESUREE/Subsystem/Constant4'])
set_param([sys,'/','Subsystem1/DERIVEE MESUREE/Subsystem/Constant4'],...
		'hide name',0,...
		'Value','instant_injection',...
		'position',[165,154,270,176])

add_block('built-in/Sum',[sys,'/','Subsystem1/DERIVEE MESUREE/Subsystem/Sum4'])
set_param([sys,'/','Subsystem1/DERIVEE MESUREE/Subsystem/Sum4'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[295,107,320,183])

add_block('built-in/MATLAB Fcn',[sys,'/',['Subsystem1/DERIVEE MESUREE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T2']])
set_param([sys,'/',['Subsystem1/DERIVEE MESUREE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T2']],...
		'MATLAB Fcn','fix(u/T)*T',...
		'Output Width','1',...
		'position',[365,128,425,162])

add_block('built-in/Sum',[sys,'/','Subsystem1/DERIVEE MESUREE/Subsystem/Sum1'])
set_param([sys,'/','Subsystem1/DERIVEE MESUREE/Subsystem/Sum1'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[475,54,495,176])

add_block('built-in/Note',[sys,'/',['Subsystem1/DERIVEE MESUREE/Subsystem/Le temps courant de la simulation',13,'commence  l''instant d''injection ']])
set_param([sys,'/',['Subsystem1/DERIVEE MESUREE/Subsystem/Le temps courant de la simulation',13,'commence  l''instant d''injection ']],...
		'Font Name','Arial',...
		'position',[175,70,180,75])
add_line([sys,'/','Subsystem1/DERIVEE MESUREE/Subsystem'],[270,125;290,125])
add_line([sys,'/','Subsystem1/DERIVEE MESUREE/Subsystem'],[500,115;520,115])
add_line([sys,'/','Subsystem1/DERIVEE MESUREE/Subsystem'],[430,145;470,145])
add_line([sys,'/','Subsystem1/DERIVEE MESUREE/Subsystem'],[275,165;290,165])
add_line([sys,'/','Subsystem1/DERIVEE MESUREE/Subsystem'],[325,145;360,145])
add_line([sys,'/','Subsystem1/DERIVEE MESUREE/Subsystem'],[345,145;345,85;470,85])
set_param([sys,'/','Subsystem1/DERIVEE MESUREE/Subsystem'],...
		'Mask Display','Mise en place\ndes priodes')


%     Finished composite block 'Subsystem1/DERIVEE MESUREE/Subsystem'.

set_param([sys,'/','Subsystem1/DERIVEE MESUREE/Subsystem'],...
		'hide name',0,...
		'position',[155,236,295,284])

add_block('built-in/Note',[sys,'/',['Subsystem1/DERIVEE MESUREE/Temps courant',13,'de la simulation']])
set_param([sys,'/',['Subsystem1/DERIVEE MESUREE/Temps courant',13,'de la simulation']],...
		'position',[70,295,75,300])

add_block('built-in/Inport',[sys,'/','Subsystem1/DERIVEE MESUREE/in_2'])
set_param([sys,'/','Subsystem1/DERIVEE MESUREE/in_2'],...
		'Port','2',...
		'position',[95,250,115,270])
add_line([sys,'/','Subsystem1/DERIVEE MESUREE'],[300,260;370,260])
add_line([sys,'/','Subsystem1/DERIVEE MESUREE'],[130,145;430,145;430,215;450,215])
add_line([sys,'/','Subsystem1/DERIVEE MESUREE'],[365,200;370,200])
add_line([sys,'/','Subsystem1/DERIVEE MESUREE'],[405,230;450,230])
add_line([sys,'/','Subsystem1/DERIVEE MESUREE'],[490,225;510,225])
add_line([sys,'/','Subsystem1/DERIVEE MESUREE'],[580,225;710,225])
add_line([sys,'/','Subsystem1/DERIVEE MESUREE'],[595,225;595,285;625,285])
add_line([sys,'/','Subsystem1/DERIVEE MESUREE'],[595,225;595,150;630,150])
add_line([sys,'/','Subsystem1/DERIVEE MESUREE'],[120,260;150,260])
set_param([sys,'/','Subsystem1/DERIVEE MESUREE'],...
		'Mask Display','DERIVEE DE B\n\nMESUREE\n\nPERIODE n')


%     Finished composite block 'Subsystem1/DERIVEE MESUREE'.

set_param([sys,'/','Subsystem1/DERIVEE MESUREE'],...
		'position',[310,260,445,340])

add_block('built-in/Sum',[sys,'/','Subsystem1/Sum'])
set_param([sys,'/','Subsystem1/Sum'],...
		'hide name',0,...
		'position',[640,134,665,321])

add_block('built-in/Outport',[sys,'/','Subsystem1/out_2'])
set_param([sys,'/','Subsystem1/out_2'],...
		'Port','2',...
		'position',[790,145,810,165])

add_block('built-in/Outport',[sys,'/','Subsystem1/out_1'])
set_param([sys,'/','Subsystem1/out_1'],...
		'position',[780,45,800,65])

add_block('built-in/Outport',[sys,'/','Subsystem1/out_3'])
set_param([sys,'/','Subsystem1/out_3'],...
		'Port','3',...
		'position',[800,390,820,410])

add_block('built-in/Note',[sys,'/','Subsystem1/Drive pulse non lisse'])
set_param([sys,'/','Subsystem1/Drive pulse non lisse'],...
		'position',[790,425,795,430])

add_block('built-in/Note',[sys,'/','Subsystem1/Champ  liss'])
set_param([sys,'/','Subsystem1/Champ  liss'],...
		'position',[775,115,780,120])

add_block('built-in/Note',[sys,'/','Subsystem1/Champ rel satellite'])
set_param([sys,'/','Subsystem1/Champ rel satellite'],...
		'position',[690,55,695,60])

add_block('built-in/Inport',[sys,'/','Subsystem1/in_2'])
set_param([sys,'/','Subsystem1/in_2'],...
		'Port','2',...
		'position',[120,310,140,330])

add_block('built-in/Inport',[sys,'/','Subsystem1/in_1'])
set_param([sys,'/','Subsystem1/in_1'],...
		'position',[115,190,135,210])
add_line([sys,'/','Subsystem1'],[140,200;295,200])
add_line([sys,'/','Subsystem1'],[275,200;190,200;190,280;225,280])
add_line([sys,'/','Subsystem1'],[440,200;580,200;580,180;635,180])
add_line([sys,'/','Subsystem1'],[440,225;455,225;455,250;530,250])
add_line([sys,'/','Subsystem1'],[450,300;530,300])
add_line([sys,'/','Subsystem1'],[670,230;725,230])
add_line([sys,'/','Subsystem1'],[565,275;635,275])
add_line([sys,'/','Subsystem1'],[290,280;305,280])
add_line([sys,'/','Subsystem1'],[145,320;305,320])
add_line([sys,'/','Subsystem1'],[440,175;465,175;465,55;775,55])
add_line([sys,'/','Subsystem1'],[475,300;475,400;795,400])
add_line([sys,'/','Subsystem1'],[685,230;685,155;785,155])
set_param([sys,'/','Subsystem1'],...
		'Mask Display','Champ rel\n&\nchamp mesur',...
		'Mask Help','Entre 1= champ satellite, entre 2=temps, sortie 1= champ satellite, sortie2= champ liss, sortie 3 = drive non lisse')


%     Finished composite block 'Subsystem1'.

set_param([sys,'/','Subsystem1'],...
		'hide name',0,...
		'position',[45,221,170,299])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
