function [ret,x0,str,ts,xts]=regderiv(t,x,u,flag);
%REGDERIV	is the M-file description of the SIMULINK system named REGDERIV.
%	The block-diagram can be displayed by typing: REGDERIV.
%
%	SYS=REGDERIV(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes REGDERIV to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling REGDERIV with a FLAG of zero:
%	[SIZES]=REGDERIV([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[62,240,1167,1098])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '5000')
set_param(sys,'Min step size', '0.1')
set_param(sys,'Max step size', '0.5')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Note',[sys,'/',['QUATERNIONS : ETUDE DU TANGAGE ROULIS ET LACET',13,'']])
set_param([sys,'/',['QUATERNIONS : ETUDE DU TANGAGE ROULIS ET LACET',13,'']],...
		'ForeGround',5,...
		'Font Name','Arial',...
		'Font Size',18,...
		'position',[490,0,495,5])

add_block('built-in/Note',[sys,'/','Stabilisation par la drive du champ magntique terrestre'])
set_param([sys,'/','Stabilisation par la drive du champ magntique terrestre'],...
		'ForeGround',5,...
		'Font Size',16,...
		'position',[478,40,483,45])

add_block('built-in/Note',[sys,'/',['4  7 = quaternion d''attitude dans le repre orbital']])
set_param([sys,'/',['4  7 = quaternion d''attitude dans le repre orbital']],...
		'position',[630,715,635,720])

add_block('built-in/Note',[sys,'/',['Vecteur d''tat de 7 composantes']])
set_param([sys,'/',['Vecteur d''tat de 7 composantes']],...
		'position',[495,695,500,700])

add_block('built-in/Note',[sys,'/','1  3 = rotation inertielle'])
set_param([sys,'/','1  3 = rotation inertielle'],...
		'position',[380,720,385,725])


%     Subsystem  'Extras1'.

new_system([sys,'/','Extras1'])
set_param([sys,'/','Extras1'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras1'],...
		'Mask Display','INITIALISATION\npar double clic souris',...
		'Mask Dialogue','eval(''derivdat'')')


%     Finished composite block 'Extras1'.

set_param([sys,'/','Extras1'],...
		'ForeGround',4,...
		'BackGround',6,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[825,425,1040,496])


%     Subsystem  'UnNamed1'.

new_system([sys,'/','UnNamed1'])
set_param([sys,'/','UnNamed1'],'Location',[110,294,976,713])


%     Subsystem  ['UnNamed1/Perturbations',13,'arodynamiques1'].

new_system([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],'Location',[-116,119,1151,725])


%     Subsystem  ['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem'].

new_system([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem']],'Location',[-309,413,916,1058])

add_block('built-in/Inport',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/in_3']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/in_3']],...
		'hide name',0,...
		'Port','3',...
		'position',[135,510,155,530])

add_block('built-in/Inport',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/in_2']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/in_2']],...
		'hide name',0,...
		'Port','2',...
		'position',[135,485,155,505])

add_block('built-in/Inport',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/in_1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/in_1']],...
		'hide name',0,...
		'position',[135,460,155,480])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/out_1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/out_1']],...
		'position',[1155,285,1175,305])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Mux']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Mux']],...
		'ForeGround',7,...
		'BackGround',0,...
		'inputs','3',...
		'position',[985,83,1015,187])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Constant1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Constant1']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','-4*Itl*vitesse_rotation^2',...
		'position',[795,88,940,112])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Constant2']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Constant2']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','3*Irl*vitesse_rotation^2',...
		'position',[795,123,940,147])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Constant3']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Constant3']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','Irt*vitesse_rotation^2',...
		'position',[795,158,940,182])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Termes rsidus de gradient',13,'et forces inertie']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Termes rsidus de gradient',13,'et forces inertie']],...
		'ForeGround',4,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[895,195,900,200])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Mux1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Mux1']],...
		'ForeGround',1,...
		'BackGround',0,...
		'inputs','3',...
		'position',[975,243,1005,347])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Constant4']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Constant4']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero1',...
		'position',[785,248,930,272])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Constant5']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Constant5']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero2',...
		'position',[785,283,930,307])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Constant6']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Constant6']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero3',...
		'position',[785,318,930,342])

add_block('built-in/Sum',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Sum']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Sum']],...
		'inputs','+++',...
		'position',[1090,244,1125,346])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/B']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/B']],...
		'position',[520,415,525,420])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/M']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/M']],...
		'position',[525,315,530,320])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Constant10']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Constant10']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','gamma',...
		'position',[130,363,275,387])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Constant11']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Constant11']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','beta',...
		'position',[130,328,275,352])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Constant12']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Constant12']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','alpha',...
		'position',[130,293,275,317])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Mux3']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Mux3']],...
		'ForeGround',1,...
		'BackGround',0,...
		'inputs','3',...
		'position',[320,288,350,392])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Vitesses',13,'inutiles']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Vitesses',13,'inutiles']],...
		'position',[150,410,155,415])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Mux4']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Mux4']],...
		'hide name',0,...
		'inputs','3',...
		'position',[185,454,225,536])


%     Subsystem  ['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite'].

new_system([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite']],'Location',[195,367,1041,836])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Equateur au temps 0 s']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Equateur au temps 0 s']],...
		'position',[460,30,465,35])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Vecteur d''tat ',13,'( 3 composantes)']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Vecteur d''tat ',13,'( 3 composantes)']],...
		'position',[305,160,310,165])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/out_1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/out_1']],...
		'position',[615,110,635,130])

add_block('built-in/Inport',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/in_1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/in_1']],...
		'position',[285,110,305,130])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Sortie Bx By Bz']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Sortie Bx By Bz']],...
		'position',[660,150,665,155])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Angles']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Angles']],...
		'position',[350,135,355,140])


%     Subsystem  ['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1'].

new_system([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],'Location',[27,258,1102,698])

add_block('built-in/Inport',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/in_2']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/in_2']],...
		'position',[120,160,140,180])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Vecteur',13,'d''tat',13,'(angles)']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Vecteur',13,'d''tat',13,'(angles)']],...
		'position',[273,165,278,170])

add_block('built-in/Clock',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Clock']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Clock']],...
		'position',[115,100,135,120])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn3']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn3']],...
		'hide name',0,...
		'MATLAB Fcn','champmgn(u)',...
		'Output Width','3')
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn3']],...
		'Mask Display','CHAMP MAGNETIQUE\nREPERE ORBITAL')
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn3']],...
		'position',[180,85,355,135])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Temps']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Temps']],...
		'position',[85,65,90,70])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Champ magntique',13,'terrestre',13,'(repre orbital)']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Champ magntique',13,'terrestre',13,'(repre orbital)']],...
		'position',[305,25,310,30])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn1']],...
		'hide name',0,...
		'MATLAB Fcn','u(1:3)''*u(4:6)')
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn1']],...
		'Output Width','1',...
		'position',[590,234,665,266])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn']],...
		'hide name',0,...
		'MATLAB Fcn','u(1:3)''*u(4:6)')
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn']],...
		'Output Width','1',...
		'position',[600,104,665,136])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Angles']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Angles']],...
		'position',[439,145,444,150])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux2']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux2']],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[540,344,570,391])

add_block('built-in/State-Space',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.3']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.3']],...
		'hide name',0,...
		'A','[]',...
		'B','[]',...
		'C','[]')
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.3']],...
		'D','K',...
		'Mask Display','Axe z',...
		'Mask Type','Matrix gain')
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.3']],...
		'Mask Dialogue','Matrix Gain:|Gain matrix:')
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.3']],...
		'Mask Translate','K = @1;')
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.3']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector.')
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.3']],...
		'Mask Entries','[0 -1 0 ;1 0 0 ;0 0 0]\/')
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.3']],...
		'position',[415,338,470,372])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn2']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn2']],...
		'hide name',0,...
		'MATLAB Fcn','u(1:3)''*u(4:6)')
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn2']],...
		'Output Width','1',...
		'position',[615,349,675,391])

add_block('built-in/Sum',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Sum2']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Sum2']],...
		'hide name',0,...
		'position',[755,339,790,381])

add_block('built-in/Sum',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Sum1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Sum1']],...
		'hide name',0,...
		'position',[755,220,770,260])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux1']],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[535,230,565,265])

add_block('built-in/State-Space',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.2']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.2']],...
		'hide name',0,...
		'A','[]',...
		'B','[]',...
		'C','[]')
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.2']],...
		'D','K',...
		'Mask Display','Axe y',...
		'Mask Type','Matrix gain')
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.2']],...
		'Mask Dialogue','Matrix Gain:|Gain matrix:')
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.2']],...
		'Mask Translate','K = @1;')
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.2']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector.')
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.2']],...
		'Mask Entries','[0 0 1;0 0 0;-1 0 0]\/')
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.2']],...
		'position',[415,223,470,257])

add_block('built-in/Sum',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Sum']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Sum']],...
		'hide name',0,...
		'position',[755,95,775,130])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/BX']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/BX']],...
		'position',[740,75,745,80])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/BY']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/BY']],...
		'position',[730,205,735,210])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux3']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux3']],...
		'hide name',0,...
		'inputs','3',...
		'position',[820,220,865,260])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/By']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/By']],...
		'position',[784,215,789,220])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux']],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[535,100,565,135])

add_block('built-in/Demux',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Demux']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Demux']],...
		'outputs','3',...
		'position',[520,44,580,76])

add_block('built-in/State-Space',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.']],...
		'hide name',0,...
		'A','[]',...
		'B','[]',...
		'C','[]')
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.']],...
		'D','K',...
		'Mask Display','Axe x',...
		'Mask Type','Matrix gain')
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.']],...
		'Mask Dialogue','Matrix Gain:|Gain matrix:')
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.']],...
		'Mask Translate','K = @1;')
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector.')
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.']],...
		'Mask Entries','[0 0 0;0 0 -1;0 1 0]\/')
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.']],...
		'position',[415,93,470,127])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/out_1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/out_1']],...
		'position',[965,230,985,250])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Champ magntique',13,'terrestre',13,'(repre satellite)']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Champ magntique',13,'terrestre',13,'(repre satellite)']],...
		'position',[910,170,915,175])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/BZ']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/BZ']],...
		'position',[715,325,720,330])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Bz']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Bz']],...
		'position',[804,290,809,295])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Bx']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Bx']],...
		'position',[804,170,809,175])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[140,110;175,110])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[870,240;960,240])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[570,120;595,120])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[475,110;530,110])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[670,120;750,120])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[670,250;750,250])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[475,240;530,240])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[570,250;585,250])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[575,370;610,370])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[475,355;535,355])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[680,370;750,370])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[145,170;510,170;510,125;530,125])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[510,170;510,380;535,380])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[510,255;530,255])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[360,110;410,110])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[380,110;380,355;410,355])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[380,240;410,240])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[775,240;815,240])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[380,110;380,60;515,60])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[585,70;690,70;690,350;750,350])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[585,60;705,60;705,230;750,230])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[585,50;720,50;720,105;750,105])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[780,115;795,115;795,225;815,225])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[795,360;795,255;815,255])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],...
		'Mask Display','Calcul du champ\nmagntique terrestre\n(repre satellite)')


%     Finished composite block ['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1'].

set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[405,84,540,156])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite']],[310,120;400,120])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite']],[545,120;610,120])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite']],...
		'Mask Display','CHAMP MAGNETIQUE EN\nAXES SATELLITE\nEntre=vecteur d''tat\nSortie Bx By Bz')


%     Finished composite block ['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite'].

set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Champ magntique',13,'en axes satellite']],...
		'position',[250,458,450,532])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Mux5']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Mux5']],...
		'inputs','[3 3]',...
		'position',[540,286,585,504])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Produit',13,'vectoriel']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Produit',13,'vectoriel']],...
		'MATLAB Fcn','prodvect(u)',...
		'Output Width','3',...
		'position',[640,378,700,412])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Moment magntique rsiduel']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Moment magntique rsiduel']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[245,246,250,251])

add_block('built-in/To Workspace',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/To Workspace']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/To Workspace']],...
		'hide name',0,...
		'mat-name','moment_residuel',...
		'buffer','5000',...
		'position',[895,440,1015,470])

add_block('built-in/Gain',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Gain']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Gain']],...
		'Gain','mom_magn_res',...
		'position',[375,315,490,365])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Produit',13,'vectoriel1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Produit',13,'vectoriel1']],...
		'MATLAB Fcn','norm(u,2)',...
		'Output Width','1',...
		'position',[770,438,830,472])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Couple arodynamique']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Couple arodynamique']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[690,277,695,282])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Couple magntique rsiduel']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Couple magntique rsiduel']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[880,399,885,404])

add_block('built-in/Gain',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Gain3']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Gain3']],...
		'hide name',0,...
		'Gain','-1',...
		'position',[800,382,835,408])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Roulis']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Roulis']],...
		'position',[110,455,115,460])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']],...
		'ForeGround',2,...
		'Font Name','Arial',...
		'Font Size',14)
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']],...
		'position',[795,550,800,555])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Tangage']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Tangage']],...
		'position',[100,485,105,490])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Lacet']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Lacet']],...
		'position',[105,510,110,515])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'Font Name','Arial')
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'Font Size',16)
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'position',[425,65,430,70])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem']],[160,520;180,520])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem']],[160,495;180,495])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem']],[160,470;180,470])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem']],[1130,295;1150,295])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem']],[1020,135;1075,135;1085,260])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem']],[935,330;970,330])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem']],[1010,295;1085,295])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem']],[935,295;970,295])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem']],[935,260;970,260])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem']],[945,170;980,170])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem']],[945,135;980,135])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem']],[945,100;980,100])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem']],[280,375;315,375])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem']],[280,340;315,340])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem']],[280,305;315,305])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem']],[355,340;370,340])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem']],[495,340;535,340])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem']],[230,495;245,495])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem']],[455,495;470,495;470,450;535,450])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem']],[590,395;635,395])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem']],[835,455;890,455])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem']],[705,395;735,395;735,455;765,455])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem']],[735,395;795,395])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem']],[840,395;1055,395;1055,330;1085,330])


%     Finished composite block ['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem'].

set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Subsystem']],...
		'position',[465,240,680,340])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/out_1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/out_1']],...
		'ForeGround',7,...
		'BackGround',0,...
		'position',[755,280,775,300])

add_block('built-in/Inport',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Inport']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Inport']],...
		'hide name',0,...
		'position',[375,245,395,265])

add_block('built-in/Inport',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Inport1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Inport1']],...
		'hide name',0,...
		'Port','2',...
		'position',[375,280,395,300])

add_block('built-in/Inport',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Inport2']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Inport2']],...
		'hide name',0,...
		'Port','3',...
		'position',[375,315,395,335])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[400,325;460,325])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[400,290;460,290])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[400,255;460,255])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[685,290;750,290])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],...
		'Mask Display','Couples\nperturbateurs Mp')


%     Finished composite block ['UnNamed1/Perturbations',13,'arodynamiques1'].

set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],...
		'ForeGround',2,...
		'hide name',0,...
		'position',[225,42,355,98])

add_block('built-in/Gain',[sys,'/','UnNamed1/Gain'])
set_param([sys,'/','UnNamed1/Gain'],...
		'Gain','0',...
		'position',[380,57,405,83])

add_block('built-in/Sum',[sys,'/','UnNamed1/Sum1'])
set_param([sys,'/','UnNamed1/Sum1'],...
		'inputs','+++',...
		'position',[440,24,480,306])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed1/magneto.m1'])
set_param([sys,'/','UnNamed1/magneto.m1'],...
		'MATLAB Fcn','derivrot(u)',...
		'Output Width','3',...
		'Mask Display','DERIVROT(u)',...
		'position',[215,234,340,286])

add_block('built-in/Inport',[sys,'/','UnNamed1/Inport'])
set_param([sys,'/','UnNamed1/Inport'],...
		'hide name',0,...
		'position',[155,40,175,60])

add_block('built-in/Inport',[sys,'/','UnNamed1/Inport1'])
set_param([sys,'/','UnNamed1/Inport1'],...
		'hide name',0,...
		'Port','2',...
		'position',[155,60,175,80])

add_block('built-in/Inport',[sys,'/','UnNamed1/Inport2'])
set_param([sys,'/','UnNamed1/Inport2'],...
		'hide name',0,...
		'Port','3',...
		'position',[155,80,175,100])

add_block('built-in/Demux',[sys,'/','UnNamed1/Demux'])
set_param([sys,'/','UnNamed1/Demux'],...
		'outputs','[3 4]',...
		'position',[95,200,145,320])

add_block('built-in/Note',[sys,'/','UnNamed1/pqr'])
set_param([sys,'/','UnNamed1/pqr'],...
		'position',[160,200,165,205])

add_block('built-in/Inport',[sys,'/','UnNamed1/Inport4'])
set_param([sys,'/','UnNamed1/Inport4'],...
		'hide name',0,...
		'Port','4',...
		'position',[40,250,60,270])

add_block('built-in/Gain',[sys,'/','UnNamed1/Gain1'])
set_param([sys,'/','UnNamed1/Gain1'],...
		'position',[500,152,525,178])

add_block('built-in/Outport',[sys,'/','UnNamed1/out_1'])
set_param([sys,'/','UnNamed1/out_1'],...
		'position',[560,155,580,175])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/To Workspace4'])
set_param([sys,'/','UnNamed1/To Workspace4'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','quater',...
		'buffer','2500',...
		'position',[205,315,270,345])

add_block('built-in/Note',[sys,'/','UnNamed1/Q'])
set_param([sys,'/','UnNamed1/Q'],...
		'position',[165,295,170,300])

add_block('built-in/Constant',[sys,'/','UnNamed1/Constant'])
set_param([sys,'/','UnNamed1/Constant'],...
		'Value','[0 0 0]''',...
		'position',[280,152,395,178])
add_line([sys,'/','UnNamed1'],[180,90;220,90])
add_line([sys,'/','UnNamed1'],[180,70;220,70])
add_line([sys,'/','UnNamed1'],[180,50;220,50])
add_line([sys,'/','UnNamed1'],[360,70;375,70])
add_line([sys,'/','UnNamed1'],[410,70;435,70])
add_line([sys,'/','UnNamed1'],[65,260;90,260])
add_line([sys,'/','UnNamed1'],[150,230;175,230;175,260;210,260])
add_line([sys,'/','UnNamed1'],[150,290;190,290;200,330])
add_line([sys,'/','UnNamed1'],[345,260;435,260])
add_line([sys,'/','UnNamed1'],[400,165;435,165])
add_line([sys,'/','UnNamed1'],[485,165;495,165])
add_line([sys,'/','UnNamed1'],[530,165;555,165])
set_param([sys,'/','UnNamed1'],...
		'Mask Display','F(X , t ) \n\nPOUR LA ROTATION')


%     Finished composite block 'UnNamed1'.

set_param([sys,'/','UnNamed1'],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[255,283,480,367])

add_block('built-in/Constant',[sys,'/','Constant1'])
set_param([sys,'/','Constant1'],...
		'hide name',0,...
		'Value','0',...
		'position',[185,305,205,325])

add_block('built-in/Constant',[sys,'/','Constant2'])
set_param([sys,'/','Constant2'],...
		'hide name',0,...
		'Value','0',...
		'position',[185,325,205,345])

add_block('built-in/Constant',[sys,'/','Constant'])
set_param([sys,'/','Constant'],...
		'hide name',0,...
		'Value','0',...
		'position',[185,285,205,305])

add_block('built-in/Note',[sys,'/','p q r Q'])
set_param([sys,'/','p q r Q'],...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[810,235,815,240])

add_block('built-in/Note',[sys,'/',['p'' q'' r'' Q''']])
set_param([sys,'/',['p'' q'' r'' Q''']],...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[810,300,815,305])


%     Subsystem  'Subsystem'.

new_system([sys,'/','Subsystem'])
set_param([sys,'/','Subsystem'],'Location',[-32000,-32000,-31840,-31975])
open_system([sys,'/','Subsystem'])

add_block('built-in/Note',[sys,'/','Subsystem/Vrifications Poinsot'])
set_param([sys,'/','Subsystem/Vrifications Poinsot'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[975,360,980,365])

add_block('built-in/Note',[sys,'/',['Subsystem/Sortie des angles',13,'roulis, lacet, tangage']])
set_param([sys,'/',['Subsystem/Sortie des angles',13,'roulis, lacet, tangage']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[605,155,610,160])

add_block('built-in/Scope',[sys,'/','Subsystem/Scope'])
set_param([sys,'/','Subsystem/Scope'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Vgain','90.000000',...
		'Hgain','50000.000000',...
		'Vmax','180.000000',...
		'Hmax','100000.000000',...
		'Window',[641,18,1021,443])
set_param([sys,'/','Subsystem/Scope'],...
		'position',[610,200,640,230])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace8'])
set_param([sys,'/','Subsystem/To Workspace8'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','temps',...
		'buffer','points_trace',...
		'position',[895,485,965,505])

add_block('built-in/Clock',[sys,'/','Subsystem/Clock'])
set_param([sys,'/','Subsystem/Clock'],...
		'position',[840,485,860,505])

add_block('built-in/Note',[sys,'/','Subsystem/Energie'])
set_param([sys,'/','Subsystem/Energie'],...
		'position',[1030,330,1035,335])

add_block('built-in/Note',[sys,'/','Subsystem/Drive de Q'])
set_param([sys,'/','Subsystem/Drive de Q'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[735,650,740,655])

add_block('built-in/Note',[sys,'/',['Subsystem/Entre de',13,' p'' q'' r'' Q''']])
set_param([sys,'/',['Subsystem/Entre de',13,' p'' q'' r'' Q''']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[450,535,455,540])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace11'])
set_param([sys,'/','Subsystem/To Workspace11'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','omega_quat',...
		'buffer','points_trace',...
		'position',[1015,604,1100,636])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace9'])
set_param([sys,'/','Subsystem/To Workspace9'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','p2plusq2',...
		'buffer','points_trace',...
		'position',[950,260,1020,280])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace10'])
set_param([sys,'/','Subsystem/To Workspace10'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','omega_tmc',...
		'buffer','points_trace',...
		'position',[935,207,1035,233])

add_block('built-in/Fcn',[sys,'/','Subsystem/Fcn'])
set_param([sys,'/','Subsystem/Fcn'],...
		'Expr','(u(1)^2+u(3)^2)^0.5',...
		'position',[865,260,905,280])

add_block('built-in/Note',[sys,'/','Subsystem/Q'])
set_param([sys,'/','Subsystem/Q'],...
		'position',[805,570,810,575])

add_block('built-in/Note',[sys,'/',['Subsystem/Q''']])
set_param([sys,'/',['Subsystem/Q''']],...
		'position',[810,650,815,655])

add_block('built-in/Mux',[sys,'/','Subsystem/Mux'])
set_param([sys,'/','Subsystem/Mux'],...
		'inputs','[4 4]',...
		'position',[835,571,870,669])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace5'])
set_param([sys,'/','Subsystem/To Workspace5'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','accel_angulaire',...
		'buffer','points_trace',...
		'position',[665,542,770,578])

add_block('built-in/Inport',[sys,'/','Subsystem/in_2'])
set_param([sys,'/','Subsystem/in_2'],...
		'Port','2',...
		'position',[440,595,460,615])

add_block('built-in/Demux',[sys,'/','Subsystem/Demux1'])
set_param([sys,'/','Subsystem/Demux1'],...
		'outputs','[3 4]',...
		'position',[585,519,635,686])

add_block('built-in/Note',[sys,'/',['Subsystem/Entre de',13,'p q r Q']])
set_param([sys,'/',['Subsystem/Entre de',13,'p q r Q']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[440,345,445,350])

add_block('built-in/Note',[sys,'/','Subsystem/Quaternion Q'])
set_param([sys,'/','Subsystem/Quaternion Q'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[700,415,705,420])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace3'])
set_param([sys,'/','Subsystem/To Workspace3'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','tangage',...
		'buffer','points_trace',...
		'position',[640,233,695,257])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/MATLAB Fcn'])
set_param([sys,'/','Subsystem/MATLAB Fcn'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','-180/pi*asin(2*(u(5)*u(7)-u(4)*u(6)))',...
		'Output Width','1',...
		'position',[545,228,605,262])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/MATLAB Fcn3'])
set_param([sys,'/','Subsystem/MATLAB Fcn3'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','ENERGIE(u)',...
		'Output Width','1',...
		'position',[890,296,970,334])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace7'])
set_param([sys,'/','Subsystem/To Workspace7'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','energie',...
		'buffer','points_trace',...
		'position',[995,305,1065,325])

add_block('built-in/Scope',[sys,'/','Subsystem/Scope3'])
set_param([sys,'/','Subsystem/Scope3'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Vgain','0.000200',...
		'Hgain','50000.000000',...
		'Vmax','0.000400',...
		'Hmax','100000.000000',...
		'Window',[305,337,635,651])
set_param([sys,'/','Subsystem/Scope3'],...
		'position',[1080,280,1110,310])

add_block('built-in/Inport',[sys,'/','Subsystem/in_1'])
set_param([sys,'/','Subsystem/in_1'],...
		'position',[430,395,450,415])

add_block('built-in/Demux',[sys,'/','Subsystem/Demux'])
set_param([sys,'/','Subsystem/Demux'],...
		'outputs','[3 4]',...
		'position',[585,319,635,486])

add_block('built-in/Note',[sys,'/',['Subsystem/SORTIES ET TRAITEMENT DE LA SORTIE',13,'POUR VERIFICATIONS DE FONCTIONNALITE']])
set_param([sys,'/',['Subsystem/SORTIES ET TRAITEMENT DE LA SORTIE',13,'POUR VERIFICATIONS DE FONCTIONNALITE']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',20,...
		'position',[610,25,615,30])

add_block('built-in/Note',[sys,'/',['Subsystem/Reste  sortir les angles',13,'',13,'']])
set_param([sys,'/',['Subsystem/Reste  sortir les angles',13,'',13,'']],...
		'position',[290,115,295,120])

add_block('built-in/Note',[sys,'/','Subsystem/Reste  mettre un stopn'])
set_param([sys,'/','Subsystem/Reste  mettre un stopn'],...
		'position',[285,145,290,150])

add_block('built-in/Note',[sys,'/','Subsystem/Reste  programmer le gradient et  le v"rifier'])
set_param([sys,'/','Subsystem/Reste  programmer le gradient et  le v"rifier'],...
		'position',[315,175,320,180])

add_block('built-in/Note',[sys,'/','Subsystem/reste  programmer la d"rive de B'])
set_param([sys,'/','Subsystem/reste  programmer la d"rive de B'],...
		'position',[305,210,310,215])

add_block('built-in/Note',[sys,'/',['Subsystem/Rotation atellite par',13,'rapport aux axes orbitaux']])
set_param([sys,'/',['Subsystem/Rotation atellite par',13,'rapport aux axes orbitaux']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[995,545,1000,550])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/MATLAB Fcn4'])
set_param([sys,'/','Subsystem/MATLAB Fcn4'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','omegaorb(u)',...
		'Output Width','3',...
		'position',[915,601,995,639])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/MATLAB Fcn5'])
set_param([sys,'/','Subsystem/MATLAB Fcn5'],...
		'ForeGround',1,...
		'BackGround',3,...
		'MATLAB Fcn','omegaabs(u)',...
		'Output Width','3',...
		'position',[930,681,1010,719])

add_block('built-in/Note',[sys,'/','Subsystem/Energie1'])
set_param([sys,'/','Subsystem/Energie1'],...
		'position',[1120,794,1125,799])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace12'])
set_param([sys,'/','Subsystem/To Workspace12'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','omega_inert',...
		'buffer','points_trace',...
		'position',[1080,684,1165,716])

add_block('built-in/Fcn',[sys,'/','Subsystem/Fcn1'])
set_param([sys,'/','Subsystem/Fcn1'],...
		'Expr','(u(1)^2+u(2)^2+u(3)^2+u(4)^2)^0.5',...
		'position',[815,435,855,455])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace14'])
set_param([sys,'/','Subsystem/To Workspace14'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','norm_quat',...
		'buffer','points_trace',...
		'position',[900,435,970,455])

add_block('built-in/Note',[sys,'/','Subsystem/1 Que pour un poinsot symtrique, la norme de la rotation absolue reste constante'])
set_param([sys,'/','Subsystem/1 Que pour un poinsot symtrique, la norme de la rotation absolue reste constante'],...
		'position',[600,710,605,715])

add_block('built-in/Note',[sys,'/',['Subsystem/J''ai vrifi :']])
set_param([sys,'/',['Subsystem/J''ai vrifi :']],...
		'position',[385,685,390,690])

add_block('built-in/Note',[sys,'/',['Subsystem/2- Que le quaternion donnant la rotation 2QQ'' a bien une premire composante nulle (  e-18 prs']])
set_param([sys,'/',['Subsystem/2- Que le quaternion donnant la rotation 2QQ'' a bien une premire composante nulle (  e-18 prs']],...
		'position',[645,730,650,735])

add_block('built-in/Scope',[sys,'/','Subsystem/Scope4'])
set_param([sys,'/','Subsystem/Scope4'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Vgain','0.020000',...
		'Hgain','5.000000',...
		'Vmax','0.040000',...
		'Hmax','10.000000',...
		'Window',[221,277,551,813])
set_param([sys,'/','Subsystem/Scope4'],...
		'position',[1170,655,1200,685])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace13'])
set_param([sys,'/','Subsystem/To Workspace13'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','energie_quat',...
		'buffer','points_trace',...
		'position',[1160,767,1245,783])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/MATLAB Fcn6'])
set_param([sys,'/','Subsystem/MATLAB Fcn6'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','ENERGIE(u)',...
		'Output Width','1',...
		'position',[1065,761,1145,799])

add_block('built-in/Note',[sys,'/','Subsystem/3- Energie constante 0.052 Joules, vrifie par la mthode TMC et celle du quaternion'])
set_param([sys,'/','Subsystem/3- Energie constante 0.052 Joules, vrifie par la mthode TMC et celle du quaternion'],...
		'position',[610,750,615,755])

add_block('built-in/Note',[sys,'/','Subsystem/4 - La norme du moment cintique est bien constante 0.0096'])
set_param([sys,'/','Subsystem/4 - La norme du moment cintique est bien constante 0.0096'],...
		'position',[540,770,545,775])
add_line([sys,'/','Subsystem'],[640,360;875,360;885,315])
add_line([sys,'/','Subsystem'],[975,315;990,315])
add_line([sys,'/','Subsystem'],[975,315;975,295;1075,295])
add_line([sys,'/','Subsystem'],[455,405;580,405])
add_line([sys,'/','Subsystem'],[640,445;810,445])
add_line([sys,'/','Subsystem'],[610,245;635,245])
add_line([sys,'/','Subsystem'],[865,495;890,495])
add_line([sys,'/','Subsystem'],[805,360;805,270;860,270])
add_line([sys,'/','Subsystem'],[910,270;945,270])
add_line([sys,'/','Subsystem'],[805,270;805,220;930,220])
add_line([sys,'/','Subsystem'],[500,405;500,245;540,245])
add_line([sys,'/','Subsystem'],[500,245;500,215;605,215])
add_line([sys,'/','Subsystem'],[465,605;580,605])
add_line([sys,'/','Subsystem'],[640,560;660,560])
add_line([sys,'/','Subsystem'],[640,645;830,645])
add_line([sys,'/','Subsystem'],[785,445;785,595;830,595])
add_line([sys,'/','Subsystem'],[875,620;910,620])
add_line([sys,'/','Subsystem'],[1000,620;1010,620])
add_line([sys,'/','Subsystem'],[1015,700;1075,700])
add_line([sys,'/','Subsystem'],[1150,780;1155,775])
add_line([sys,'/','Subsystem'],[1045,700;1045,780;1060,780])
add_line([sys,'/','Subsystem'],[860,445;895,445])
add_line([sys,'/','Subsystem'],[890,620;890,700;925,700])
add_line([sys,'/','Subsystem'],[1025,700;1025,670;1165,670])
set_param([sys,'/','Subsystem'],...
		'Mask Display','SORTIE DES ANGLES\n\nEN DEGRES & ENERGIE')


%     Finished composite block 'Subsystem'.

set_param([sys,'/','Subsystem'],...
		'hide name',0,...
		'position',[865,246,1060,319])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'hide name',0,...
		'inputs','[3 4]',...
		'position',[555,257,595,533])

add_block('built-in/Note',[sys,'/',['Entres',13,'drive rotation (3)']])
set_param([sys,'/',['Entres',13,'drive rotation (3)']],...
		'position',[600,205,605,210])

add_block('built-in/Note',[sys,'/','4'])
set_param([sys,'/','4'],...
		'position',[535,440,540,445])

add_block('built-in/Note',[sys,'/','3'])
set_param([sys,'/','3'],...
		'position',[540,300,545,305])


%     Subsystem  'UnNamed2'.

new_system([sys,'/','UnNamed2'])
set_param([sys,'/','UnNamed2'],'Location',[588,239,931,333])

add_block('built-in/Note',[sys,'/',['UnNamed2/Drive du quaternion d''attitude']])
set_param([sys,'/',['UnNamed2/Drive du quaternion d''attitude']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[185,5,190,10])

add_block('built-in/Outport',[sys,'/','UnNamed2/Outport'])
set_param([sys,'/','UnNamed2/Outport'],...
		'position',[260,45,280,65])

add_block('built-in/Inport',[sys,'/','UnNamed2/Inport'])
set_param([sys,'/','UnNamed2/Inport'],...
		'position',[80,45,100,65])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed2/deriv_qt.m'])
set_param([sys,'/','UnNamed2/deriv_qt.m'],...
		'MATLAB Fcn','deriv_qt(u)',...
		'Output Width','4',...
		'position',[150,39,220,71])
add_line([sys,'/','UnNamed2'],[225,55;255,55])
add_line([sys,'/','UnNamed2'],[105,55;145,55])
set_param([sys,'/','UnNamed2'],...
		'Mask Display','F(X , t)\n\nPOUR LE QUATERNION')


%     Finished composite block 'UnNamed2'.

set_param([sys,'/','UnNamed2'],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[255,413,470,517])

add_block('built-in/Note',[sys,'/','Drive quaternion (4)'])
set_param([sys,'/','Drive quaternion (4)'],...
		'position',[585,535,590,540])

add_block('built-in/Integrator',[sys,'/','Integrator'])
set_param([sys,'/','Integrator'],...
		'hide name',0,...
		'Initial','[vp0 vq0 vr0 qt00 qt10 qt20 qt30]',...
		'position',[645,369,745,421])

add_block('built-in/Note',[sys,'/','Il manque le calcul des angles  partir du quaternion'])
set_param([sys,'/','Il manque le calcul des angles  partir du quaternion'],...
		'position',[475,90,480,95])
add_line(sys,[750,395;770,395;770,665;40,665;40,465;250,465])
add_line(sys,[600,395;640,395])
add_line(sys,[485,325;550,325])
add_line(sys,[40,475;40,355;250,355])
add_line(sys,[475,465;550,465])
add_line(sys,[210,295;250,295])
add_line(sys,[210,315;250,315])
add_line(sys,[210,335;250,335])
add_line(sys,[770,395;770,265;860,265])
add_line(sys,[620,395;620,300;860,300])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
